@@ -538,9 +538,9 @@ Annotations.from_stack(stack).has_error("/Default/Foo", "we do not want a Foo::B
 
 Here are the available APIs for `Annotations`:
 
-* `hasError()` and `findError()`
-* `hasWarning()` and `findWarning()`
-* `hasInfo()` and `findInfo()`
+* `hasError()`, `hasNoError()`, and `findError()`
+* `hasWarning()`, `hasNoWarning()`, and `findWarning()`
+* `hasInfo()`, `hasNoInfo()`, and `findInfo()`
 
 The corresponding `findXxx()` API is complementary to the `hasXxx()` API, except instead
 of asserting its presence, it returns the set of matching messages.
@@ -654,6 +654,33 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         '''
         return typing.cast(None, jsii.invoke(self, "hasInfo", [construct_path, message]))
 
+    @jsii.member(jsii_name="hasNoError")
+    def has_no_error(self, construct_path: builtins.str, message: typing.Any) -> None:
+        '''Assert that an error with the given message does not exist in the synthesized CDK ``Stack``.
+
+        :param construct_path: the construct path to the error. Provide ``'*'`` to match all errors in the template.
+        :param message: the error message as should be expected. This should be a string or Matcher object.
+        '''
+        return typing.cast(None, jsii.invoke(self, "hasNoError", [construct_path, message]))
+
+    @jsii.member(jsii_name="hasNoInfo")
+    def has_no_info(self, construct_path: builtins.str, message: typing.Any) -> None:
+        '''Assert that an info with the given message does not exist in the synthesized CDK ``Stack``.
+
+        :param construct_path: the construct path to the info. Provide ``'*'`` to match all info in the template.
+        :param message: the info message as should be expected. This should be a string or Matcher object.
+        '''
+        return typing.cast(None, jsii.invoke(self, "hasNoInfo", [construct_path, message]))
+
+    @jsii.member(jsii_name="hasNoWarning")
+    def has_no_warning(self, construct_path: builtins.str, message: typing.Any) -> None:
+        '''Assert that an warning with the given message does not exist in the synthesized CDK ``Stack``.
+
+        :param construct_path: the construct path to the warning. Provide ``'*'`` to match all warnings in the template.
+        :param message: the warning message as should be expected. This should be a string or Matcher object.
+        '''
+        return typing.cast(None, jsii.invoke(self, "hasNoWarning", [construct_path, message]))
+
     @jsii.member(jsii_name="hasWarning")
     def has_warning(self, construct_path: builtins.str, message: typing.Any) -> None:
         '''Assert that an warning with the given message exists in the synthesized CDK ``Stack``.
